bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.__init__
=================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.__init__